%global racoonconfdir %{_sysconfdir}/racoon
%global _hardened_build 1

%{?build_selinux}%{?!build_selinux:%bcond_with selinux}

Summary:	Tools for configuring and using IPSEC
Name:		ipsec-tools
Version:	0.8.2
Release:	7
License:	BSD
Group:		Networking/Other
Url:		http://ipsec-tools.sourceforge.net/
Source0:	ftp://ftp.netbsd.org/pub/NetBSD/misc/ipsec-tools/0.8/ipsec-tools-%{version}.tar.bz2
Source1:	racoon.conf
Source2:	psk.txt
Source3:	p1_up_down
Source4:	racoon.service
Source5:	racoon.pam
Source6:	ifup-ipsec
Source7:	ifdown-ipsec
# Ignore acquires that are sent by kernel for SAs that are already being
# negotiated (#234491)
Patch3:		ipsec-tools-0.8.0-acquires.patch
# Support for labeled IPSec on loopback
Patch4:		ipsec-tools-0.8.0-loopback.patch
# Create racoon as PIE
Patch11:	ipsec-tools-0.7.1-pie.patch
# Fix leak in certification handling
Patch14:	ipsec-tools-0.7.2-moreleaks.patch
# Do not install development files
Patch16:	ipsec-tools-0.8.0-nodevel.patch
# Use krb5 gssapi mechanism
Patch18:	ipsec-tools-0.7.3-gssapi-mech.patch
# Drop -R from linker
Patch19:	ipsec-tools-0.7.3-build.patch
# Silence strict aliasing warnings
Patch20:	ipsec-tools-0.8.0-aliasing.patch
# CVE-2015-4047
Patch21:	ipsec-tools-0.8.2-CVE-2015-4047.patch
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	libtool
BuildRequires:	systemd-units
BuildRequires:	pam-devel
BuildRequires:	openldap-devel
%if %{with selinux}
BuildRequires:	audit-libs-devel >= 1.3.1
BuildRequires:	selinux-devel
%endif
BuildRequires:	pkgconfig(krb5)
BuildRequires:	pkgconfig(openssl)
Requires:	pam
Requires(post,preun,postun):	systemd
Provides:	kvpnc-backend
# No longer provided and not used by anything
Obsoletes:	%{_lib}ipsec0 < 0.8.1
Obsoletes:	%{_lib}ipsec-devel < 0.8.1

%description
This package contains tools necessary for establishing keys for IPSEC
connections including the rekeying during the connection lifetime.

The main tools of this package are:

- setkey, a program to directly manipulate policies and SAs in the kernel
- racoon, an IKEv1 keying daemon

%files
%doc src/racoon/samples/racoon.conf src/racoon/samples/psk.txt
%doc src/racoon/doc/FAQ
%doc ChangeLog NEWS README
/sbin/*
%{_sbindir}/*
%{_mandir}/man*/*
%{_unitdir}/racoon.service
%dir %{racoonconfdir}
%{racoonconfdir}/scripts/*
%dir %{racoonconfdir}/certs
%dir %{racoonconfdir}/scripts
%dir %{_localstatedir}/racoon
%config(noreplace) %{racoonconfdir}/psk.txt
%config(noreplace) %{racoonconfdir}/racoon.conf
%config(noreplace) %{_sysconfdir}/pam.d/racoon
%{_sysconfdir}/sysconfig/network-scripts/ifup-ipsec
%{_sysconfdir}/sysconfig/network-scripts/ifdown-ipsec

%post
if [ $1 -eq 1 ] ; then
/bin/systemctl preset racoon.service >/dev/null 2>&1 || :
fi

%preun
if [ $1 -eq 0 ] ; then
# Package removal, not upgrade
/bin/systemctl --no-reload disable racoon.service > /dev/null 2>&1 || :
/bin/systemctl stop racoon.service > /dev/null 2>&1 || :
fi

%postun
if [ $1 -ge 1 ] ; then
# Package upgrade, not uninstall
/bin/systemctl try-restart racoon.service >/dev/null 2>&1 || :
fi

#----------------------------------------------------------------------------

%prep
%setup -q
%patch3 -p1 -b .acquires
%patch4 -p1 -b .loopback

%patch11 -p1 -b .pie
%patch14 -p1 -b .moreleaks
%patch16 -p1 -b .nodevel
%patch18 -p1 -b .gssapi-mech
%patch19 -p1 -b .build
%patch20 -p1 -b .aliasing
%patch21 -p1 -b .cve_2015_4047

./bootstrap

%build
# Needed because some bad sizeof()'s
sed -i 's|-Werror||g' configure
# Needed to avoid error on gethostbyname, enable full relro
LDFLAGS="$LDFLAGS -Wl,--as-needed"
# Enable full relro hardening
export LDFLAGS="$LDFLAGS -fPIC -pie -Wl,-z,relro -Wl,-z,now"
%configure \
	--with-kernel-headers=/usr/include \
	--sysconfdir=%{racoonconfdir} \
	--without-readline \
	--enable-adminport \
	--enable-hybrid \
	--enable-frag \
	--enable-dpd \
	--enable-gssapi \
	--enable-natt \
%if %{with selinux}
	--enable-audit \
	--enable-security-context \
	--enable-selinux \
%else
	--disable-audit \
	--disable-security-context \
	--disable-selinux \
%endif
	--with-libpam \
	--with-libldap
# --with-libradius requires an unknown radius library
# and complains about our -liconv being broken.
make

%install
mkdir -p %{buildroot}/sbin
mkdir -p %{buildroot}%{racoonconfdir}
%makeinstall_std

install -m 600 %{SOURCE1} %{buildroot}%{racoonconfdir}/racoon.conf
install -m 600 %{SOURCE2} %{buildroot}%{racoonconfdir}/psk.txt

mv %{buildroot}%{_sbindir}/setkey %{buildroot}/sbin

mkdir -m 0700 -p %{buildroot}%{racoonconfdir}/certs
mkdir -m 0700 -p %{buildroot}%{racoonconfdir}/scripts
install -m 700 %{SOURCE3} %{buildroot}%{racoonconfdir}/scripts/p1_up_down
install -D -m 755 %{SOURCE4} %{buildroot}%{_unitdir}/racoon.service
install -D -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/pam.d/racoon

mkdir -m 0755 -p %{buildroot}%{_sysconfdir}/sysconfig/network-scripts
install -p -m 755 %{SOURCE6} %{SOURCE7} %{buildroot}%{_sysconfdir}/sysconfig/network-scripts


%changelog

* Tue Mar 08 2016 Denis Silakov <dsilakov@gmail.com> 0.8.2-7
- (424fe5b) Bump release


